Crate trident_derive_flow_executor

Crate trident_derive_flow_executor 

Attribute Macros

end
Marks a method to run once after all flow methods
flow
Marks a method to be executed as part of the fuzzing flow
flow_executor
Implements the flow executor for a struct
init
Marks a method to run once before any flow methods